@@ -75,14 +75,19 @@ so: `rustup run <toolchain> <COMMAND...>`. You'll only need to provide the <COMM
                     .takes_value(false)
                 )
                 .arg(Arg::with_name(id::ARG_MIN)
-                    .long("minimum")
+                    .long("min")
+                    .visible_alias("minimum")
                     .help("Earliest version to take into account")
-                    .long_help("Earliest version to take into account.")
+                    .long_help("Earliest (least recent) version to take into account. \
+                     Version must match a valid Rust toolchain, and be semver compatible.")
                     .takes_value(true)
                 )
                 .arg(Arg::with_name(id::ARG_MAX)
-                    .long("maximum")
+                    .long("max")
+                    .visible_alias("maximum")
                     .help("Latest version to take into account")
+                    .long_help("Latest (most recent) version to take into account.\
+                     Version must match a valid Rust toolchain, and be semver compatible.")
                     .takes_value(true)
                 )
                 .arg(Arg::with_name(id::ARG_BISECT)
